==> keycloak-model-map-hot-rod-19.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodScopeEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodScopeEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Scope.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.HotRodScopeEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodScopeEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodScopeEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Scope.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodScopeEntity.HotRodScopeEntitySchema.INSTANCE;
    }
}
